@@ -19,20 +19,20 @@ module.exports = generators.Base.extend({
 
     this.argument('appName', { type: String, required: false });
     this.option('appName', { type: String, required: false });
-    this.option('appId', { type: String, required: false });
+    /*this.option('appId', { type: String, required: false });
     this.option('compass', { type: Boolean, required: false });
     this.option('starter', { type: String, required: false });
     this.option('templates', { type: Array, required: false });
-    this.option('plugins', { type: Object, required: false });
+    this.option('plugins', { type: Object, required: false });*/
     this.option('auth', { type: Object, required: false });
-    this.option('flurry', { type: Object, required: false });
-    this.option('push', { type: Object, required: false });
+    /*this.option('flurry', { type: Object, required: false });
+    this.option('push', { type: Object, required: false });*/
     this.options.selected = {};
     this.lplugins = [];
   },
 
   prompting: {
-    askForCompass: function askForCompass() {
+    /*askForCompass: function askForCompass() {
       var done = this.async();
 
       this.prompt([{
@@ -86,23 +86,21 @@ module.exports = generators.Base.extend({
 
         done();
       }.bind(this));
-    },
+    },*/
     askForAuthentificationProvider: function askForAuthentificationProvider() {
       var done = this.async();
-      console.log('!!!!!!!!!');
-      console.log(this.options.auth);
-      if (this.options.auth) {
-        console.log('!!!!!!!!!');
-        ionicUtils.mergePlugins(this.options.auth);
-      }
-      console.log(this.options.auth);
+      /*if (this.options.auth) {
+        console.log('OPTIONS')
+        ionicUtils.mergeAuthProvider(this.options.auth);
+      }*/
 
       this.prompt(ionicUtils.auth.prompts, function (props) {
+        console.log(props);        
         this.auth = this.options.selected.auth = props.auth;
         console.log(this.auth);
         done();
       }.bind(this));
-    },
+    }/*,
     askForStarter: function askForStarter() {
       var done = this.async();
 
@@ -132,7 +130,7 @@ module.exports = generators.Base.extend({
         this.starter = this.options.selected.starter = _.find(ionicUtils.starters.templates, { name: props.starter });
         done();
       }.bind(this));
-    }
+    }*/
 
   },
 
@@ -186,16 +184,13 @@ module.exports = generators.Base.extend({
       }.bind(this));
     },
     installAuthProvider: function installAuthProvider() {
+      console.log(this.auth);
       if (this.auth) {
         var done = this.async();
-        var self = this;
-        console.log(this.auth);
-        done();
-      } else {
-        console.log('NO AUTH');
+        ionicUtils.auth.install(this, this.auth, done);
       }
     },
-    installPush: function installPush() {
+    /*installPush: function installPush() {
       if (this.push) {
         var self = this;
         var done = this.async();
@@ -286,7 +281,7 @@ module.exports = generators.Base.extend({
       } else {
         this.remote(this.starter.user, this.starter.repo, 'master', callback, true);
       }
-    },
+    },*/
 
     readIndex: function readIndex() {
       this.indexFile = this.engine(this.read(path.join(this.starterCache, 'index.html')), this);
